powercurve.t.test <-
function(...) {

  cat("\n"); cat( # stop(call.=FALSE, "\n","------\n",
    ">>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>\n",
    " The function  powercurve.t.test has been renamed.\n\n",
    " Now use  ttp   instead of  powercurve.t.test.\n",
    "<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<\n\n", sep="")

  ttp(...)

  cat("\n"); cat( # stop(call.=FALSE, "\n","------\n",
    ">>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>\n",
    " The function  powercurve.t.test has been renamed.\n\n",
    " Now use  ttp   instead of  powercurve.t.test.\n",
    "<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<\n\n", sep="")

}
